summaryrefslogtreecommitdiffstats
path: root/languages/ruby/debugger/dbgtoolbar.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-16 13:53:18 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-16 13:53:18 -0600
commit2ecab1a194b0dc551b478820e1aaa3b8713354cc (patch)
treeae4df71ed26f3dc2dd605970d8d455165a1c8ab3 /languages/ruby/debugger/dbgtoolbar.cpp
parent549fec618f0b15c9316fc0a5ebe93c2829bc0b1b (diff)
downloadtdevelop-2ecab1a194b0dc551b478820e1aaa3b8713354cc.tar.gz
tdevelop-2ecab1a194b0dc551b478820e1aaa3b8713354cc.zip
Additional renaming of kde to tde
Diffstat (limited to 'languages/ruby/debugger/dbgtoolbar.cpp')
-rw-r--r--languages/ruby/debugger/dbgtoolbar.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/languages/ruby/debugger/dbgtoolbar.cpp b/languages/ruby/debugger/dbgtoolbar.cpp
index 0b96201f..3b13b148 100644
--- a/languages/ruby/debugger/dbgtoolbar.cpp
+++ b/languages/ruby/debugger/dbgtoolbar.cpp
@@ -1,7 +1,7 @@
/***************************************************************************
begin : Thu Dec 23 1999
copyright : (C) 1999 by John Birch
- email : jbb@kdevelop.org
+ email : jbb@tdevelop.org
Adapted for ruby debugging
--------------------------
@@ -57,7 +57,7 @@
// So, if you can get it to work as a KToolBar, and it works well when the
// app is running, then all these classes can be removed.
// This code is very specific to the internal debugger in kdevelop.
namespace RDBDebugger
{
@@ -304,7 +304,7 @@ DbgToolBar::DbgToolBar(RubyDebuggerPart* part,
TQPushButton* bFinish = new DbgButton(BarIcon("dbgstepout"), i18n("Step Out"), this);
TQPushButton* bRunTo = new DbgButton(BarIcon("dbgrunto"), i18n("Run to Cursor"), this);
bPrevFocus_ = new DbgButton(BarIcon("dbgmemview"), TQString(), this);
- bKDevFocus_ = new DbgButton(BarIcon("kdevelop"), TQString(), this);
+ bKDevFocus_ = new DbgButton(BarIcon("tdevelop"), TQString(), this);
connect(bRun, TQT_SIGNAL(clicked()), part_, TQT_SLOT(slotRun()));
connect(bInterrupt, TQT_SIGNAL(clicked()), part_, TQT_SLOT(slotPause()));
@@ -385,7 +385,7 @@ void DbgToolBar::slotKdevFocus()
{
// I really want to be able to set the focus on the _application_ being debugged
// but this is the best compromise I can come up with. All we do is save the
// window that had focus when they switch to the kdevelop window. To do this
// the toolbar _cannot_ accept focus.
// If anyone has a way of determining what window the app is _actually_ running on
// then please fix and send a patch.
@@ -57,7 +57,7 @@
// So, if you can get it to work as a KToolBar, and it works well when the
// app is running, then all these classes can be removed.
-// This code is very specific to the internal debugger in kdevelop.
+// This code is very specific to the internal debugger in tdevelop.
namespace RDBDebugger
{
@@ -385,7 +385,7 @@ void DbgToolBar::slotKdevFocus()
// I really want to be able to set the focus on the _application_ being debugged
// but this is the best compromise I can come up with. All we do is save the
- // window that had focus when they switch to the kdevelop window. To do this
+ // window that had focus when they switch to the tdevelop window. To do this
// the toolbar _cannot_ accept focus.
// If anyone has a way of determining what window the app is _actually_ running on